==> haskell-servant-0.13.0.1-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.13.0.1
id: servant-0.13.0.1-BE0KAwZQLgNElmwv3SSjX0
key: servant-0.13.0.1-BE0KAwZQLgNElmwv3SSjX0
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 5b907ac65d7afc9ddd6f31fe86e2c115
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Utils.Enter
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-0.13.0.1
hs-libraries: HSservant-0.13.0.1-BE0KAwZQLgNElmwv3SSjX0
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    aeson-1.3.1.1-4Y3ALHMQQEYEDTh2988ctY
    attoparsec-0.13.2.2-9zRGjV3As3w1B2ujiZf4yU
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-api-data-0.3.8.1-2tz8xwQ1ZaB4jUivSogP0Q
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-1FEEescNY7H9pB2LVhivNI
    natural-transformation-0.4-H812UKihNmSBjnMSucJuXM
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    vault-0.3.1.1-I37kX1z9VsY1JRMJRQcCRw
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             aeson-1.3.1.1-4Y3ALHMQQEYEDTh2988ctY=4a6f3fa3d72c8a9dbe85892dfb85eb93
             attoparsec-0.13.2.2-9zRGjV3As3w1B2ujiZf4yU=970180ace34b66d93bd5b25ba2c2a659
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             http-api-data-0.3.8.1-2tz8xwQ1ZaB4jUivSogP0Q=05f884bf0ffc3c46ad0f93efcf558a26
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             http-types-0.12.1-1FEEescNY7H9pB2LVhivNI=b54600906e288a2a11c67e3d97adc11c
             natural-transformation-0.4-H812UKihNmSBjnMSucJuXM=f01044c1c5505f881c9688077a5c6ece
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=24df0dfc182470190a9b6f84de345a01
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             vault-0.3.1.1-I37kX1z9VsY1JRMJRQcCRw=0310282ff180efd2645571b2a26dbf79
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.13.0.1-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.13.0.1
id: servant-0.13.0.1-FNhhmxrD3zH5TWk8AcBSIl
key: servant-0.13.0.1-FNhhmxrD3zH5TWk8AcBSIl
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: ca14524029dac802d501f5598336a8bd
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Utils.Enter
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-0.13.0.1
hs-libraries: HSservant-0.13.0.1-FNhhmxrD3zH5TWk8AcBSIl
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    aeson-1.3.1.1-6HkD4IOtKBsKBv5cbRyt47
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-api-data-0.3.8.1-7V5OnCQ59z8FYWTajildiL
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    natural-transformation-0.4-H812UKihNmSBjnMSucJuXM
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    vault-0.3.1.1-I37kX1z9VsY1JRMJRQcCRw
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             aeson-1.3.1.1-6HkD4IOtKBsKBv5cbRyt47=f2b384712f64489a53b966926a554aaf
             attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             http-api-data-0.3.8.1-7V5OnCQ59z8FYWTajildiL=862d5c5cef6402769ce17d28a6488005
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             natural-transformation-0.4-H812UKihNmSBjnMSucJuXM=f01044c1c5505f881c9688077a5c6ece
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=24df0dfc182470190a9b6f84de345a01
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             vault-0.3.1.1-I37kX1z9VsY1JRMJRQcCRw=0310282ff180efd2645571b2a26dbf79
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
